﻿/*
 * Copyright 2010 Canonical Ltd.
 * 
 * This file is part of Ubuntu One on Windows.
 * 
 * Ubuntu One on Windows is free software: you can redistribute it and/or modify		
 * it under the terms of the GNU Lesser General Public License version 		
 * as published by the Free Software Foundation.		
 *		
 * Ubuntu One on Windows is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the	
 * GNU Lesser General Public License for more details.	
 *
 * You should have received a copy of the GNU Lesser General Public License	
 * along with Ubuntu One for Windows.  If not, see <http://www.gnu.org/licenses/>.
 * 
 * Authors: Manuel de la Peña <manuel.delapena@canonical.com>
 */
using System;
using System.Collections.Generic;
using Canonical.UbuntuOne.Common.Aop;

namespace Canonical.Ubuntu.SSO
{
    /// <summary>
    /// Implementation of the SSOCredentials provider that uses the DAPI framework to encrypt the
    /// data and store it in the registry.
    /// </summary>
    public class SSOCredentialsProvider : ISSOCredentialsProvider
    {
        #region DI properties

        public ILoginView LoginView { get; set; }

        public IKeyring Keyring { get; set; }

        #endregion

        #region Implementation of ISSOCredentialsProvider

        public event EventHandler<CredentialsFoundEventArgs> OnCredentialsFound;
        public event EventHandler<CredentialsDeniedEventArgs> OnCredetialsDenied;
        public event EventHandler<CredentialsErrorEventArgs> OnCredentialsError;

        /// <summary>
        /// This method will try to fetch the encrypted credentials from the registry and 
        /// return them, and if the credentials are not found it will open a 
        /// dialog letting the user just log into an existing account via the 
        /// Ubuntu SSO webservice, and will then get the related credentials, 
        /// store them into the keyring for future usage and finally return them.
        /// 
        /// The result of this action will be notified through the use of the event handlers
        /// due to the fact that the call to the sso webservice is async.
        /// </summary>
        [DebugLogged]
        public void LoginToGetCredentials()
        {
            // try to get the credentials from the keyring
            
        }

        /// <summary>
        /// This method will try to fetch the credentials from the registry and return them, 
        /// and if the credentials are not found it will open a dialog letting the user 
        /// either register a new or log into an existing account via the Ubuntu SSO webservice, 
        /// and will then get the related credentials, store them into the registry for future 
        /// usage and finally return them.
        /// 
        /// The result of this action will be notified through the use of the event handlers
        /// due to the fact that the call to the sso webservice is async.
        /// </summary>
        [DebugLogged]
        public void LoginOrRegisterToGetCredentials()
        {
        }

        #endregion
    }
}
